@@ -1,9 +1,9 @@
 import os
-import pathlib
+from pathlib import Path
 import json
 from typing import Any
 
-BASE_DIR = pathlib.Path(__file__).parent.absolute()
+BASE_DIR = Path(__file__).parent.absolute()
 
 
 class Config:
@@ -14,13 +14,14 @@ class Config:
     # protect user from scanning entire system when run in root
     RECURSION_DEPTH = 10
 
-    # load version from package.json for npm package
-    with open(os.path.join(BASE_DIR, "..", "package.json"), "r") as file:
-        VERSION = json.load(file)["version"]
+    ROOT_DIR = BASE_DIR
+    STATIC_DIR = BASE_DIR / "app" / "static"
 
-    with open(os.path.join(BASE_DIR, "section_index.schema.json"), "r") as file:
+    VERSION = "v0.2.6"
+
+    with open(BASE_DIR / "section_index.schema.json", "r") as file:
         SECTION_INDEX_SCHEMA = json.load(file)
-    with open(os.path.join(BASE_DIR, "project.schema.json"), "r") as file:
+    with open(BASE_DIR / "project.schema.json", "r") as file:
         PROJECT_SCHEMA = json.load(file)
 
     @staticmethod
