@@ -1,6 +1,6 @@
 """Load a Manim Editor project."""
-import os
 from fractions import Fraction
+from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
 
 from .manim_loader import Section, valid_json_load
@@ -28,15 +28,15 @@ def get_project_section(raw_section: Dict[str, Any]) -> Section:
     )
 
 
-def get_project(path: str) -> Tuple[Optional[str], List[Section]]:
+def get_project(name: str) -> Tuple[Optional[str], List[Section]]:
     """Parse project json file if valid.
     ``path`` is path to prject dir, not to the json index file.
     Otherwise return ``None`` as name.
     """
-    raw_sections = valid_json_load(os.path.join(path, "project.json"), get_config().PROJECT_SCHEMA)
+    path = Path(name)
+    raw_sections = valid_json_load(path / "project.json", get_config().PROJECT_SCHEMA)
     if raw_sections is None:
         return None, []
-    name = os.path.basename(path)
     sections: List[Section] = []
     for raw_section in raw_sections:
         sections.append(get_project_section(raw_section))
@@ -47,14 +47,14 @@ def get_projects() -> Dict[str, List[Section]]:
     """Get all projects in the current working directory.
     No recursive search will be applied."""
     # get all projects in this dir
-    project_paths: List[str] = []
-    for root, _, files in walk(".", 1):
+    project_paths: List[Path] = []
+    for root, _, files in walk(Path("."), 1):
         for file in files:
             if file == "project.json":
                 project_paths.append(root)
     projects: Dict[str, List[Section]] = {}
-    for project_path in project_paths:
-        name, sections = get_project(project_path)
+    for project_name in project_paths:
+        name, sections = get_project(str(project_name))
         # don't include invalid
         if name is not None:
             projects[name] = sections
